@@ -3,8 +3,8 @@
    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
+#include "config/noteactionconfig.h"
 #include <KPluginFactory>
-#include <config/noteactionconfig.h>
 
 K_PLUGIN_CLASS_WITH_JSON(NoteShared::NoteActionConfig, "kcm_knote_action.json")
 
